==> haskell-wai-extra-3.0.28-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.28
id: wai-extra-3.0.28-5ez3nCd9iMt8Np0iYgQkI0
key: wai-extra-3.0.28-5ez3nCd9iMt8Np0iYgQkI0
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: 2ff328732f083727223185d0894ee841
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-extra-3.0.28
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-extra-3.0.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-extra-3.0.28
hs-libraries: HSwai-extra-3.0.28-5ez3nCd9iMt8Np0iYgQkI0
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    directory-1.3.3.0 fast-logger-2.4.17-F1bssgEZmrB1QgkAoK7p6e
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    http2-2.0.3-TnRGUhhK2j2GYqluUuoIM
    iproute-1.7.7-H1PvQD4fsqSF5DZuimogPc
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    vault-0.3.1.3-JZ0YCyq9z4kGqiaSc3dflW
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-logger-2.3.5-CdAnQLymRdgIS8KyjkwlQX
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.28-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.28
id: wai-extra-3.0.28-1ai1gncnCzmJyD6zsOcLM3
key: wai-extra-3.0.28-1ai1gncnCzmJyD6zsOcLM3
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: 2a1ef3cc06c5e234d2a4dd238f829122
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-extra-3.0.28
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-extra-3.0.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-extra-3.0.28
hs-libraries: HSwai-extra-3.0.28-1ai1gncnCzmJyD6zsOcLM3
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    directory-1.3.3.0 fast-logger-2.4.17-Cd6ZUQsGKTSHW7YusNSTv8
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    http2-2.0.3-1iyPIWVK82PAEQlFWeaWbM
    iproute-1.7.7-H1PvQD4fsqSF5DZuimogPc
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    vault-0.3.1.3-JZ0YCyq9z4kGqiaSc3dflW
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-logger-2.3.5-IHtbK0Oi7xL6CNeVsqU25P
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
